# History

## Next milestones

- 3D Pareto front (w, t, b)
- Standardize cost function
- Sanitize cost function

## 0.1.1 (2026-02-06): First public release

- Dropped Python 3.10 support (now requires Python 3.11+).
- Fixed type hint in `CostModel` (`down_matrix` was `np.array` instead of `np.ndarray`).
- Removed unused imports in `smart_cruise.py`.
- Updated README with proper quickstart example.
- Fixed documentation issues.

## 0.1.0 (2025-05-15): First release

- First release on PyPI.
